pub struct NousMiddleware { /* private fields */ }Expand description
Arcan middleware that runs Nous evaluators at each hook point.
Created with a populated EvaluatorRegistry and runs the appropriate
evaluators at each lifecycle hook. Scores are accumulated and can be
retrieved after a run completes.
Implementations
Sourceimpl NousMiddleware
impl NousMiddleware
Sourcepub fn new(registry: EvaluatorRegistry) -> Self
pub fn new(registry: EvaluatorRegistry) -> Self
Create a new middleware with the given evaluator registry.
Sourcepub fn with_on_score(
registry: EvaluatorRegistry,
on_score: Arc<dyn Fn(&EvalScore) + Send + Sync>,
) -> Self
pub fn with_on_score( registry: EvaluatorRegistry, on_score: Arc<dyn Fn(&EvalScore) + Send + Sync>, ) -> Self
Create a middleware with a score callback.
Sourcepub fn with_defaults() -> Result<Self, NousError>
pub fn with_defaults() -> Result<Self, NousError>
Create a middleware with the default heuristic evaluators.
Sourcepub fn registry_len(&self) -> usize
pub fn registry_len(&self) -> usize
Number of registered evaluators.